@@ -48,7 +48,7 @@ class Server(object):
 
 		if self._key_path:
 			kwargs.update({
-				'pkey': paramiko.RSAKey.from_private_key_file(self.key_path)
+				'pkey': paramiko.RSAKey.from_private_key_file(self._key_path)
 			})
 
 		if hasattr(self, '_port'):
