@@ -6,28 +6,28 @@ class Clean(Server):
 
 	_choice = None
 
-	valid_choices = [
+	valid_services = [
 		None, 'fastcgi', 'memcache', 'opcache', 'pagespeed', 'redir', 'all'
 	]
 
-	def is_valid_choice(self):
-		if self._choice in self.valid_choices:
+	def is_valid_service(self):
+		if self._service in self.valid_services:
 			return True
 
 		return False
 
-	def do(self, choice=None):
+	def do(self, service=None):
 		if self.is_install():
 			raise EasyEngineException
 
-		if choice:
-			self._choice = choice
+		if service:
+			self._service = service
 
-		if not self.is_valid_choice():
+		if not self.is_valid_service():
 			return self.response(False)
 
-		if self._choice:
-			stdin, stdout, stderr = self.execute('ee clean --%s' % self._choice)
+		if self._service:
+			stdin, stdout, stderr = self.execute('ee clean --%s' % self._service)
 		else:
 			stdin, stdout, stderr = self.execute('ee clean')
 		
